@@ -33,9 +33,10 @@
 #  define KROSSCORE_DEPRECATED_NO_EXPORT KROSSCORE_NO_EXPORT KROSSCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KROSSCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KROSSCORE_NO_DEPRECATED
+#    define KROSSCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
